@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: http-client
-version: 0.4.26.2
-id: http-client-0.4.26.2-c2eaefc770ba5c6095150732f28d8ca8
-key: httpc_In6bKV2pflCAZ2LtcwPavN
+version: 0.4.27
+id: http-client-0.4.27-cb2c2811d5497a3b5f8310fdf3cadc3f
+key: httpc_9RkeBIAHS47BQVHTYHIVjh
 license: MIT
 maintainer: michael@snoyman.com
 homepage: https://github.com/snoyberg/http-client
@@ -25,31 +25,31 @@ hidden-modules: Network.HTTP.Client.Body
                 Network.PublicSuffixList.Types Network.PublicSuffixList.Serialize
                 Network.PublicSuffixList.DataStructure
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/http-client-0.4.26.2
-library-dirs: /usr/lib/ghc-7.10.3/site-local/http-client-0.4.26.2
-data-dir: /usr/share/arm-linux-ghc-7.10.3/http-client-0.4.26.2
-hs-libraries: HShttp-client-0.4.26.2-In6bKV2pflCAZ2LtcwPavN
+import-dirs: /usr/lib/ghc-7.10.3/site-local/http-client-0.4.27
+library-dirs: /usr/lib/ghc-7.10.3/site-local/http-client-0.4.27
+data-dir: /usr/share/arm-linux-ghc-7.10.3/http-client-0.4.27
+hs-libraries: HShttp-client-0.4.27-9RkeBIAHS47BQVHTYHIVjh
 depends:
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
-    blaze-builder-0.4.0.1-adef087994cafeb1970772b79d5f710a
+    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    case-insensitive-1.2.0.5-0be5e2a885602c48fdae255d4ef6b04b
+    case-insensitive-1.2.0.5-6669cd7a393ccedc4f66c0a01b6f0e2f
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    cookie-0.4.1.6-4f449d11b0217aec9c8aeaf7af398a96
+    cookie-0.4.1.6-8a746b417cee9e54ae77a0b2d5e8515e
     data-default-class-0.0.1-fcbab95490d730dd2489b628499587cd
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
     exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
     ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
-    http-types-0.9-26f1bedc2b9255e48a8e673fef6095b1
-    mime-types-0.1.0.6-4baf8227dab0a657ebdceeda13c342d3
+    http-types-0.9-d392878af9c5e1b1993961dc71a9e177
+    mime-types-0.1.0.6-1ae582cd69235deb20f7c2577dd8b3dc
     network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
-    network-uri-2.6.0.3-f06058f927fb674b53980227bb9fbb26
+    network-uri-2.6.0.3-27316eb865f3b3562ae77903534d67a4
     random-1.1-41a0a7ecd483c665a5c3a093a5be2968
-    streaming-commons-0.1.15-bfe5dd5a0dc219d23135213ca9f37753
-    text-1.2.1.3-6c3c87c392cdf2c29fca1c10bbf7250b
+    streaming-commons-0.1.15-43ddfb983feecf5e5c9c7ab99b5e44ed
+    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
 haddock-interfaces: /usr/share/doc/haskell-http-client/html/http-client.haddock
